#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-9v3HBQCsZYf74OTjYxwVEA
key:                  gtk-strut-0.1.3.2-9v3HBQCsZYf74OTjYxwVEA
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  fdc0afbe344669b0a09a8de39929331e
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-9v3HBQCsZYf74OTjYxwVEA
depends:
    base-4.18.2.1 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    gi-gdk-3.0.29-5Qc28FxC5f02rSCCVosXXB
    gi-gtk-3.0.43-9qWRduwXu2d5hM3exipUKr
    hslogger-1.3.2.0-J16AmHi76RmEIcf2UoXdPr text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

